@@ -5,7 +5,8 @@ from typing import Any, Dict, List
 import pandas as pd
 
 from freqtrade.configuration import TimeRange
-from freqtrade.data.btanalysis import (calculate_max_drawdown, combine_dataframes_with_mean,
+from freqtrade.data.btanalysis import (analyze_trade_parallelism, calculate_max_drawdown,
+                                       calculate_underwater, combine_dataframes_with_mean,
                                        create_cum_profit, extract_trades_of_period, load_trades)
 from freqtrade.data.converter import trim_dataframe
 from freqtrade.data.dataprovider import DataProvider
@@ -160,7 +161,7 @@ def add_max_drawdown(fig, row, trades: pd.DataFrame, df_comb: pd.DataFrame,
     Add scatter points indicating max drawdown
     """
     try:
-        max_drawdown, highdate, lowdate, _, _ = calculate_max_drawdown(trades)
+        _, highdate, lowdate, _, _, max_drawdown = calculate_max_drawdown(trades)
 
         drawdown = go.Scatter(
             x=[highdate, lowdate],
@@ -185,6 +186,48 @@ def add_max_drawdown(fig, row, trades: pd.DataFrame, df_comb: pd.DataFrame,
     return fig
 
 
+def add_underwater(fig, row, trades: pd.DataFrame) -> make_subplots:
+    """
+    Add underwater plot
+    """
+    try:
+        underwater = calculate_underwater(trades, value_col="profit_abs")
+
+        underwater = go.Scatter(
+            x=underwater['date'],
+            y=underwater['drawdown'],
+            name="Underwater Plot",
+            fill='tozeroy',
+            fillcolor='#cc362b',
+            line={'color': '#cc362b'},
+        )
+        fig.add_trace(underwater, row, 1)
+    except ValueError:
+        logger.warning("No trades found - not plotting underwater plot")
+    return fig
+
+
+def add_parallelism(fig, row, trades: pd.DataFrame, timeframe: str) -> make_subplots:
+    """
+    Add Chart showing trade parallelism
+    """
+    try:
+        result = analyze_trade_parallelism(trades, timeframe)
+
+        drawdown = go.Scatter(
+            x=result.index,
+            y=result['open_trades'],
+            name="Parallel trades",
+            fill='tozeroy',
+            fillcolor='#242222',
+            line={'color': '#242222'},
+        )
+        fig.add_trace(drawdown, row, 1)
+    except ValueError:
+        logger.warning("No trades found - not plotting Parallelism.")
+    return fig
+
+
 def plot_trades(fig, trades: pd.DataFrame) -> make_subplots:
     """
     Add trades to "fig"
@@ -192,10 +235,12 @@ def plot_trades(fig, trades: pd.DataFrame) -> make_subplots:
     # Trades can be empty
     if trades is not None and len(trades) > 0:
         # Create description for sell summarizing the trade
-        trades['desc'] = trades.apply(lambda row: f"{row['profit_ratio']:.2%}, "
-                                                  f"{row['sell_reason']}, "
-                                                  f"{row['trade_duration']} min",
-                                      axis=1)
+        trades['desc'] = trades.apply(
+            lambda row: f"{row['profit_ratio']:.2%}, " +
+            (f"{row['buy_tag']}, " if row['buy_tag'] is not None else "") +
+            f"{row['sell_reason']}, " +
+            f"{row['trade_duration']} min",
+            axis=1)
         trade_buys = go.Scatter(
             x=trades["open_date"],
             y=trades["open_rate"],
@@ -460,7 +505,12 @@ def generate_candlestick_graph(pair: str, data: pd.DataFrame, trades: pd.DataFra
 def generate_profit_graph(pairs: str, data: Dict[str, pd.DataFrame],
                           trades: pd.DataFrame, timeframe: str, stake_currency: str) -> go.Figure:
     # Combine close-values for all pairs, rename columns to "pair"
-    df_comb = combine_dataframes_with_mean(data, "close")
+    try:
+        df_comb = combine_dataframes_with_mean(data, "close")
+    except ValueError:
+        raise OperationalException(
+            "No data found. Please make sure that data is available for "
+            "the timerange and pairs selected.")
 
     # Trim trades to available OHLCV data
     trades = extract_trades_of_period(df_comb, trades, date_index=True)
@@ -477,20 +527,30 @@ def generate_profit_graph(pairs: str, data: Dict[str, pd.DataFrame],
         name='Avg close price',
     )
 
-    fig = make_subplots(rows=3, cols=1, shared_xaxes=True,
-                        row_width=[1, 1, 1],
+    fig = make_subplots(rows=5, cols=1, shared_xaxes=True,
+                        row_heights=[1, 1, 1, 0.5, 1],
                         vertical_spacing=0.05,
-                        subplot_titles=["AVG Close Price", "Combined Profit", "Profit per pair"])
+                        subplot_titles=[
+                            "AVG Close Price",
+                            "Combined Profit",
+                            "Profit per pair",
+                            "Parallelism",
+                            "Underwater",
+                            ])
     fig['layout'].update(title="Freqtrade Profit plot")
     fig['layout']['yaxis1'].update(title='Price')
     fig['layout']['yaxis2'].update(title=f'Profit {stake_currency}')
     fig['layout']['yaxis3'].update(title=f'Profit {stake_currency}')
+    fig['layout']['yaxis4'].update(title='Trade count')
+    fig['layout']['yaxis5'].update(title='Underwater Plot')
     fig['layout']['xaxis']['rangeslider'].update(visible=False)
     fig.update_layout(modebar_add=["v1hovermode", "toggleSpikeLines"])
 
     fig.add_trace(avgclose, 1, 1)
     fig = add_profit(fig, 2, df_comb, 'cum_profit', 'Profit')
     fig = add_max_drawdown(fig, 2, trades, df_comb, timeframe)
+    fig = add_parallelism(fig, 4, trades, timeframe)
+    fig = add_underwater(fig, 5, trades)
 
     for pair in pairs:
         profit_col = f'cum_profit_{pair}'
