@@ -68,14 +68,14 @@ class PerformanceFilter(IPairList):
         #  - then pair name alphametically
         sorted_df = list_df.merge(performance, on='pair', how='left')\
             .fillna(0).sort_values(by=['count', 'pair'], ascending=True)\
-            .sort_values(by=['profit'], ascending=False)
+            .sort_values(by=['profit_ratio'], ascending=False)
         if self._min_profit is not None:
-            removed = sorted_df[sorted_df['profit'] < self._min_profit]
+            removed = sorted_df[sorted_df['profit_ratio'] < self._min_profit]
             for _, row in removed.iterrows():
                 self.log_once(
-                    f"Removing pair {row['pair']} since {row['profit']} is "
+                    f"Removing pair {row['pair']} since {row['profit_ratio']} is "
                     f"below {self._min_profit}", logger.info)
-            sorted_df = sorted_df[sorted_df['profit'] >= self._min_profit]
+            sorted_df = sorted_df[sorted_df['profit_ratio'] >= self._min_profit]
 
         pairlist = sorted_df['pair'].tolist()
 
