@@ -7,7 +7,7 @@ import datetime
 import logging
 from typing import Dict, List
 
-from cachetools.ttl import TTLCache
+from cachetools import TTLCache
 from pycoingecko import CoinGeckoAPI
 from requests.exceptions import RequestException
 
@@ -77,6 +77,9 @@ class CryptoToFiatConverter:
             else:
                 return None
         found = [x for x in self._coinlistings if x['symbol'] == crypto_symbol]
+        if crypto_symbol == 'eth':
+            found = [x for x in self._coinlistings if x['id'] == 'ethereum']
+
         if len(found) == 1:
             return found[0]['id']
 
