@@ -1,5 +1,5 @@
 # pragma pylint: disable=missing-docstring,W0212,C0103
-from datetime import datetime
+from datetime import datetime, timedelta
 from pathlib import Path
 from unittest.mock import ANY, MagicMock
 
@@ -22,6 +22,29 @@ from tests.conftest import (get_args, log_has, log_has_re, patch_exchange,
                             patched_configuration_load_config_file)
 
 
+def generate_result_metrics():
+    return {
+            'trade_count': 1,
+            'total_trades': 1,
+            'avg_profit': 0.1,
+            'total_profit': 0.001,
+            'profit': 0.01,
+            'duration': 20.0,
+            'wins': 1,
+            'draws': 0,
+            'losses': 0,
+            'profit_mean': 0.01,
+            'profit_total_abs': 0.001,
+            'profit_total': 0.01,
+            'holding_avg': timedelta(minutes=20),
+            'max_drawdown': 0.001,
+            'max_drawdown_abs': 0.001,
+            'loss': 0.001,
+            'is_initial_point': 0.001,
+            'is_best': 1,
+        }
+
+
 def test_setup_hyperopt_configuration_without_arguments(mocker, default_conf, caplog) -> None:
     patched_configuration_load_config_file(mocker, default_conf)
 
@@ -168,7 +191,8 @@ def test_start_no_hyperopt_allowed(mocker, hyperopt_conf, caplog) -> None:
         start_hyperopt(pargs)
 
 
-def test_start_no_data(mocker, hyperopt_conf) -> None:
+def test_start_no_data(mocker, hyperopt_conf, tmpdir) -> None:
+    hyperopt_conf['user_data_dir'] = Path(tmpdir)
     patched_configuration_load_config_file(mocker, hyperopt_conf)
     mocker.patch('freqtrade.data.history.load_pair_history', MagicMock(return_value=pd.DataFrame))
     mocker.patch(
@@ -177,7 +201,6 @@ def test_start_no_data(mocker, hyperopt_conf) -> None:
     )
 
     patch_exchange(mocker)
-    # TODO: migrate to strategy-based hyperopt
     args = [
         'hyperopt',
         '--config', 'config.json',
@@ -189,6 +212,12 @@ def test_start_no_data(mocker, hyperopt_conf) -> None:
     with pytest.raises(OperationalException, match='No data found. Terminating.'):
         start_hyperopt(pargs)
 
+    # Cleanup since that failed hyperopt start leaves a lockfile.
+    try:
+        Path(Hyperopt.get_lock_filename(hyperopt_conf)).unlink()
+    except Exception:
+        pass
+
 
 def test_start_filelock(mocker, hyperopt_conf, caplog) -> None:
     hyperopt_mock = MagicMock(side_effect=Timeout(Hyperopt.get_lock_filename(hyperopt_conf)))
@@ -215,14 +244,7 @@ def test_log_results_if_loss_improves(hyperopt, capsys) -> None:
     hyperopt.print_results(
         {
             'loss': 1,
-            'results_metrics':
-                {
-                    'trade_count': 1,
-                    'avg_profit': 0.1,
-                    'total_profit': 0.001,
-                    'profit': 1.0,
-                    'duration': 20.0
-                },
+            'results_metrics': generate_result_metrics(),
             'total_profit': 0,
             'current_epoch': 2,  # This starts from 1 (in a human-friendly manner)
             'is_initial_point': False,
@@ -231,7 +253,7 @@ def test_log_results_if_loss_improves(hyperopt, capsys) -> None:
     )
     out, err = capsys.readouterr()
     assert all(x in out
-               for x in ["Best", "2/2", " 1", "0.10%", "0.00100000 BTC    (1.00%)", "20.0 m"])
+               for x in ["Best", "2/2", " 1", "0.10%", "0.00100000 BTC    (1.00%)", "00:20:00"])
 
 
 def test_no_log_if_loss_does_not_improve(hyperopt, caplog) -> None:
@@ -288,14 +310,7 @@ def test_start_calls_optimizer(mocker, hyperopt_conf, capsys) -> None:
         MagicMock(return_value=[{
             'loss': 1, 'results_explanation': 'foo result',
             'params': {'buy': {}, 'sell': {}, 'roi': {}, 'stoploss': 0.0},
-            'results_metrics':
-            {
-                'trade_count': 1,
-                'avg_profit': 0.1,
-                'total_profit': 0.001,
-                'profit': 1.0,
-                'duration': 20.0
-            },
+            'results_metrics': generate_result_metrics(),
         }])
     )
     patch_exchange(mocker)
@@ -352,7 +367,7 @@ def test_hyperopt_format_results(hyperopt):
         'backtest_start_time': 1619718665,
         'backtest_end_time': 1619718665,
     }
-    results_metrics = generate_strategy_stats({'XRP/BTC': None}, '', bt_result,
+    results_metrics = generate_strategy_stats(['XRP/BTC'], '', bt_result,
                                               Arrow(2017, 11, 14, 19, 32, 00),
                                               Arrow(2017, 12, 14, 19, 32, 00), market_change=0)
 
@@ -521,14 +536,7 @@ def test_print_json_spaces_all(mocker, hyperopt_conf, capsys) -> None:
                 'roi': {}, 'stoploss': {'stoploss': None},
                 'trailing': {'trailing_stop': None}
             },
-            'results_metrics':
-            {
-                'trade_count': 1,
-                'avg_profit': 0.1,
-                'total_profit': 0.001,
-                'profit': 1.0,
-                'duration': 20.0
-            }
+            'results_metrics': generate_result_metrics(),
         }])
     )
     patch_exchange(mocker)
@@ -577,14 +585,7 @@ def test_print_json_spaces_default(mocker, hyperopt_conf, capsys) -> None:
                 'sell': {'sell-mfi-value': None},
                 'roi': {}, 'stoploss': {'stoploss': None}
             },
-            'results_metrics':
-            {
-                'trade_count': 1,
-                'avg_profit': 0.1,
-                'total_profit': 0.001,
-                'profit': 1.0,
-                'duration': 20.0
-            }
+            'results_metrics': generate_result_metrics(),
         }])
     )
     patch_exchange(mocker)
@@ -622,14 +623,7 @@ def test_print_json_spaces_roi_stoploss(mocker, hyperopt_conf, capsys) -> None:
         MagicMock(return_value=[{
             'loss': 1, 'results_explanation': 'foo result', 'params': {},
             'params_details': {'roi': {}, 'stoploss': {'stoploss': None}},
-            'results_metrics':
-            {
-                'trade_count': 1,
-                'avg_profit': 0.1,
-                'total_profit': 0.001,
-                'profit': 1.0,
-                'duration': 20.0
-            }
+            'results_metrics': generate_result_metrics(),
         }])
     )
     patch_exchange(mocker)
@@ -669,14 +663,7 @@ def test_simplified_interface_roi_stoploss(mocker, hyperopt_conf, capsys) -> Non
         'freqtrade.optimize.hyperopt.Hyperopt.run_optimizer_parallel',
         MagicMock(return_value=[{
             'loss': 1, 'results_explanation': 'foo result', 'params': {'stoploss': 0.0},
-            'results_metrics':
-            {
-                'trade_count': 1,
-                'avg_profit': 0.1,
-                'total_profit': 0.001,
-                'profit': 1.0,
-                'duration': 20.0
-            }
+            'results_metrics': generate_result_metrics(),
         }])
     )
     patch_exchange(mocker)
@@ -749,14 +736,7 @@ def test_simplified_interface_buy(mocker, hyperopt_conf, capsys) -> None:
         'freqtrade.optimize.hyperopt.Hyperopt.run_optimizer_parallel',
         MagicMock(return_value=[{
             'loss': 1, 'results_explanation': 'foo result', 'params': {},
-            'results_metrics':
-            {
-                'trade_count': 1,
-                'avg_profit': 0.1,
-                'total_profit': 0.001,
-                'profit': 1.0,
-                'duration': 20.0
-            }
+            'results_metrics': generate_result_metrics(),
         }])
     )
     patch_exchange(mocker)
@@ -798,14 +778,7 @@ def test_simplified_interface_sell(mocker, hyperopt_conf, capsys) -> None:
         'freqtrade.optimize.hyperopt.Hyperopt.run_optimizer_parallel',
         MagicMock(return_value=[{
             'loss': 1, 'results_explanation': 'foo result', 'params': {},
-            'results_metrics':
-            {
-                'trade_count': 1,
-                'avg_profit': 0.1,
-                'total_profit': 0.001,
-                'profit': 1.0,
-                'duration': 20.0
-            }
+            'results_metrics': generate_result_metrics(),
         }])
     )
     patch_exchange(mocker)
