@@ -533,6 +533,7 @@ def test_api_show_config(botclient):
     assert rc.json()['timeframe_min'] == 5
     assert rc.json()['state'] == 'running'
     assert rc.json()['bot_name'] == 'freqtrade'
+    assert rc.json()['strategy_version'] is None
     assert not rc.json()['trailing_stop']
     assert 'bid_strategy' in rc.json()
     assert 'ask_strategy' in rc.json()
@@ -954,6 +955,38 @@ def test_api_blacklist(botclient, mocker):
                          "errors": {},
                          }
 
+    rc = client_delete(client, f"{BASE_URI}/blacklist?pairs_to_delete=DOGE/BTC")
+    assert_response(rc)
+    assert rc.json() == {"blacklist": ["HOT/BTC", "ETH/BTC", "XRP/.*"],
+                         "blacklist_expanded": ["ETH/BTC", "XRP/BTC", "XRP/USDT"],
+                         "length": 3,
+                         "method": ["StaticPairList"],
+                         "errors": {},
+                         }
+
+    rc = client_delete(client, f"{BASE_URI}/blacklist?pairs_to_delete=NOTHING/BTC")
+    assert_response(rc)
+    assert rc.json() == {"blacklist": ["HOT/BTC", "ETH/BTC", "XRP/.*"],
+                         "blacklist_expanded": ["ETH/BTC", "XRP/BTC", "XRP/USDT"],
+                         "length": 3,
+                         "method": ["StaticPairList"],
+                         "errors": {
+                             "NOTHING/BTC": {
+                                 "error_msg": "Pair NOTHING/BTC is not in the current blacklist."
+                             }
+                             },
+                         }
+    rc = client_delete(
+        client,
+        f"{BASE_URI}/blacklist?pairs_to_delete=HOT/BTC&pairs_to_delete=ETH/BTC")
+    assert_response(rc)
+    assert rc.json() == {"blacklist": ["XRP/.*"],
+                         "blacklist_expanded": ["XRP/BTC", "XRP/USDT"],
+                         "length": 1,
+                         "method": ["StaticPairList"],
+                         "errors": {},
+                         }
+
 
 def test_api_whitelist(botclient):
     ftbot, client = botclient
@@ -1293,7 +1326,7 @@ def test_sysinfo(botclient):
     assert 'ram_pct' in result
 
 
-def test_api_backtesting(botclient, mocker, fee, caplog):
+def test_api_backtesting(botclient, mocker, fee, caplog, tmpdir):
     ftbot, client = botclient
     mocker.patch('freqtrade.exchange.Exchange.get_fee', fee)
 
@@ -1314,6 +1347,11 @@ def test_api_backtesting(botclient, mocker, fee, caplog):
     assert result['status'] == 'reset'
     assert not result['running']
     assert result['status_msg'] == 'Backtest reset'
+    ftbot.config['export'] = 'trades'
+    ftbot.config['backtest_cache'] = 'none'
+    ftbot.config['user_data_dir'] = Path(tmpdir)
+    ftbot.config['exportfilename'] = Path(tmpdir) / "backtest_results"
+    ftbot.config['exportfilename'].mkdir()
 
     # start backtesting
     data = {
@@ -1388,6 +1426,14 @@ def test_api_backtesting(botclient, mocker, fee, caplog):
     rc = client_post(client, f"{BASE_URI}/backtest", data=json.dumps(data))
     assert log_has("Backtesting caused an error: ", caplog)
 
+    ftbot.config['backtest_cache'] = 'day'
+
+    # Rerun backtest (should get previous result)
+    rc = client_post(client, f"{BASE_URI}/backtest", data=json.dumps(data))
+    assert_response(rc)
+    result = rc.json()
+    assert log_has_re('Reusing result of previous backtest.*', caplog)
+
     # Delete backtesting to avoid leakage since the backtest-object may stick around.
     rc = client_delete(client, f"{BASE_URI}/backtest")
     assert_response(rc)
